@@ -24,16 +24,10 @@ model_parameters.glmmTMB <- function(model,
                                      keep = NULL,
                                      drop = NULL,
                                      verbose = TRUE,
-                                     df_method = ci_method,
                                      include_sigma = FALSE,
                                      ...) {
   insight::check_if_installed("glmmTMB")
 
-  ## TODO remove later
-  if (!missing(df_method) && !identical(ci_method, df_method)) {
-    insight::format_error("Argument `df_method` is defunct. Please use `ci_method` instead.")
-  }
-
   # sanity check, warn if unsupported argument is used.
   dot_args <- .check_dots(
     dots = list(...),
