@@ -1,4 +1,3 @@
-
 #' @rdname model_parameters.principal
 #' @export
 model_parameters.sem <- model_parameters.default
@@ -10,9 +9,9 @@ standard_error.sem <- function(model, ...) {
     return(NULL)
   }
   if (is.null(model$se)) {
-    warning(insight::format_message(
+    insight::format_warning(
       "Model has no standard errors. Please fit model again with bootstrapped standard errors."
-    ), call. = FALSE)
+    )
     return(NULL)
   }
   .data_frame(
