@@ -1,9 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
 
-if (.runThisTest &&
-  requiet("testthat") &&
-  requiet("parameters") &&
-  requiet("lme4")) {
+if (.runThisTest && requiet("lme4")) {
   data("cbpp")
   set.seed(123)
   model <- glmer(
